@@ -1,16 +1,33 @@
-# mutate ------------------------------------------------------------------
-
+#' Create, modify, and delete columns
+#'
+#' These are methods for the dplyr [mutate()] and [transmute()] generics.
+#' They are translated to computed expressions in the `SELECT` clause of
+#' the SQL query.
+#'
+#' @inheritParams arrange.tbl_lazy
+#' @inheritParams dplyr::mutate
+#' @inherit arrange.tbl_lazy return
 #' @export
 #' @importFrom dplyr mutate
-mutate.tbl_lazy <- function(.data, ..., .dots = list()) {
+#' @examples
+#' library(dplyr, warn.conflicts = FALSE)
+#'
+#' db <- memdb_frame(x = 1:5, y = 5:1)
+#' db %>%
+#'   mutate(a = (x + y) / 2, b = sqrt(x^2L + y^2L)) %>%
+#'   show_query()
+#'
+#' # dbplyr automatically creates subqueries as needed
+#' db %>%
+#'   mutate(x1 = x + 1, x2 = x1 * 2) %>%
+#'   show_query()
+mutate.tbl_lazy <- function(.data, ...) {
   dots <- quos(..., .named = TRUE)
   dots <- partial_eval_dots(dots, vars = op_vars(.data))
 
   nest_vars(.data, dots, union(op_vars(.data), op_grps(.data)))
 }
 
-# transmute ---------------------------------------------------------------
-
 #' @export
 #' @importFrom dplyr transmute
 transmute.tbl_lazy <- function(.data, ...) {
@@ -33,7 +50,8 @@ nest_vars <- function(.data, dots, all_vars) {
     used_vars <- all_names(get_expr(dots[[i]]))
 
     if (any(used_vars %in% new_vars)) {
-      .data$ops <- op_select(.data$ops, carry_over(all_vars, dots[new_vars]))
+      new_actions <- dots[seq2(init, length(dots))][new_vars]
+      .data$ops <- op_select(.data$ops, carry_over(union(all_vars, used_vars), new_actions))
       all_vars <- c(all_vars, setdiff(new_vars, all_vars))
       new_vars <- cur_var
       init <- i
