@@ -21,7 +21,7 @@ test_that("queries translate correctly", {
 test_that("generates custom sql", {
   con <- simulate_oracle()
 
-  expect_snapshot(sql_table_analyze(con, ident("table")))
+  expect_snapshot(sql_table_analyze(con, in_schema("schema", "tbl")))
   expect_snapshot(sql_query_explain(con, sql("SELECT * FROM foo")))
 
   lf <- lazy_frame(x = 1, con = con)
